@@ -17,11 +17,11 @@ import (
 	"github.com/schollz/cli/v2"
 	"github.com/schollz/croc/v10/src/comm"
 	"github.com/schollz/croc/v10/src/croc"
+	"github.com/schollz/croc/v10/src/mnemonicode"
 	"github.com/schollz/croc/v10/src/models"
 	"github.com/schollz/croc/v10/src/tcp"
 	"github.com/schollz/croc/v10/src/utils"
 	log "github.com/schollz/logger"
-	"github.com/schollz/mnemonicode"
 	"github.com/schollz/pake/v3"
 )
 
@@ -36,7 +36,7 @@ func Run() (err error) {
 	app := cli.NewApp()
 	app.Name = "croc"
 	if Version == "" {
-		Version = "v10.0.12"
+		Version = "v10.1.0"
 	}
 	app.Version = Version
 	app.Compiled = time.Now()
@@ -108,6 +108,7 @@ func Run() (err error) {
 		&cli.BoolFlag{Name: "ignore-stdin", Usage: "ignore piped stdin"},
 		&cli.BoolFlag{Name: "overwrite", Usage: "do not prompt to overwrite or resume"},
 		&cli.BoolFlag{Name: "testing", Usage: "flag for testing purposes"},
+		&cli.StringFlag{Name: "multicast", Value: "239.255.255.250", Usage: "multicast address to use for local discovery"},
 		&cli.StringFlag{Name: "curve", Value: "p256", Usage: "choose an encryption curve (" + strings.Join(pake.AvailableCurves(), ", ") + ")"},
 		&cli.StringFlag{Name: "ip", Value: "", Usage: "set sender ip if known e.g. 10.0.0.1:9009, [::1]:9009"},
 		&cli.StringFlag{Name: "relay", Value: models.DEFAULT_RELAY, Usage: "address of the relay", EnvVars: []string{"CROC_RELAY"}},
@@ -279,28 +280,29 @@ func send(c *cli.Context) (err error) {
 	}
 
 	crocOptions := croc.Options{
-		SharedSecret:   c.String("code"),
-		IsSender:       true,
-		Debug:          c.Bool("debug"),
-		NoPrompt:       c.Bool("yes"),
-		RelayAddress:   c.String("relay"),
-		RelayAddress6:  c.String("relay6"),
-		Stdout:         c.Bool("stdout"),
-		DisableLocal:   c.Bool("no-local"),
-		OnlyLocal:      c.Bool("local"),
-		IgnoreStdin:    c.Bool("ignore-stdin"),
-		RelayPorts:     ports,
-		Ask:            c.Bool("ask"),
-		NoMultiplexing: c.Bool("no-multi"),
-		RelayPassword:  determinePass(c),
-		SendingText:    c.String("text") != "",
-		NoCompress:     c.Bool("no-compress"),
-		Overwrite:      c.Bool("overwrite"),
-		Curve:          c.String("curve"),
-		HashAlgorithm:  c.String("hash"),
-		ThrottleUpload: c.String("throttleUpload"),
-		ZipFolder:      c.Bool("zip"),
-		GitIgnore:      c.Bool("git"),
+		SharedSecret:     c.String("code"),
+		IsSender:         true,
+		Debug:            c.Bool("debug"),
+		NoPrompt:         c.Bool("yes"),
+		RelayAddress:     c.String("relay"),
+		RelayAddress6:    c.String("relay6"),
+		Stdout:           c.Bool("stdout"),
+		DisableLocal:     c.Bool("no-local"),
+		OnlyLocal:        c.Bool("local"),
+		IgnoreStdin:      c.Bool("ignore-stdin"),
+		RelayPorts:       ports,
+		Ask:              c.Bool("ask"),
+		NoMultiplexing:   c.Bool("no-multi"),
+		RelayPassword:    determinePass(c),
+		SendingText:      c.String("text") != "",
+		NoCompress:       c.Bool("no-compress"),
+		Overwrite:        c.Bool("overwrite"),
+		Curve:            c.String("curve"),
+		HashAlgorithm:    c.String("hash"),
+		ThrottleUpload:   c.String("throttleUpload"),
+		ZipFolder:        c.Bool("zip"),
+		GitIgnore:        c.Bool("git"),
+		MulticastAddress: c.String("multicast"),
 	}
 	if crocOptions.RelayAddress != models.DEFAULT_RELAY {
 		crocOptions.RelayAddress6 = ""
@@ -358,6 +360,7 @@ func send(c *cli.Context) (err error) {
 		if err != nil {
 			return
 		}
+		utils.MarkFileForRemoval(fnames[0])
 		defer func() {
 			e := os.Remove(fnames[0])
 			if e != nil {
@@ -369,6 +372,7 @@ func send(c *cli.Context) (err error) {
 		if err != nil {
 			return
 		}
+		utils.MarkFileForRemoval(fnames[0])
 		defer func() {
 			e := os.Remove(fnames[0])
 			if e != nil {
@@ -523,20 +527,21 @@ func receive(c *cli.Context) (err error) {
 	comm.Socks5Proxy = c.String("socks5")
 	comm.HttpProxy = c.String("connect")
 	crocOptions := croc.Options{
-		SharedSecret:  c.String("code"),
-		IsSender:      false,
-		Debug:         c.Bool("debug"),
-		NoPrompt:      c.Bool("yes"),
-		RelayAddress:  c.String("relay"),
-		RelayAddress6: c.String("relay6"),
-		Stdout:        c.Bool("stdout"),
-		Ask:           c.Bool("ask"),
-		RelayPassword: determinePass(c),
-		OnlyLocal:     c.Bool("local"),
-		IP:            c.String("ip"),
-		Overwrite:     c.Bool("overwrite"),
-		Curve:         c.String("curve"),
-		TestFlag:      c.Bool("testing"),
+		SharedSecret:     c.String("code"),
+		IsSender:         false,
+		Debug:            c.Bool("debug"),
+		NoPrompt:         c.Bool("yes"),
+		RelayAddress:     c.String("relay"),
+		RelayAddress6:    c.String("relay6"),
+		Stdout:           c.Bool("stdout"),
+		Ask:              c.Bool("ask"),
+		RelayPassword:    determinePass(c),
+		OnlyLocal:        c.Bool("local"),
+		IP:               c.String("ip"),
+		Overwrite:        c.Bool("overwrite"),
+		Curve:            c.String("curve"),
+		TestFlag:         c.Bool("testing"),
+		MulticastAddress: c.String("multicast"),
 	}
 	if crocOptions.RelayAddress != models.DEFAULT_RELAY {
 		crocOptions.RelayAddress6 = ""
