@@ -12,22 +12,23 @@ import (
 	"math"
 	"net"
 	"os"
+	"os/exec"
 	"path"
 	"path/filepath"
+	"runtime"
 	"strconv"
 	"strings"
 	"sync"
 	"time"
 
-	"golang.org/x/term"
-	"golang.org/x/time/rate"
-
 	"github.com/denisbrodbeck/machineid"
 	ignore "github.com/sabhiram/go-gitignore"
 	log "github.com/schollz/logger"
 	"github.com/schollz/pake/v3"
 	"github.com/schollz/peerdiscovery"
 	"github.com/schollz/progressbar/v3"
+	"golang.org/x/term"
+	"golang.org/x/time/rate"
 
 	"github.com/schollz/croc/v10/src/comm"
 	"github.com/schollz/croc/v10/src/compress"
@@ -58,31 +59,32 @@ func Debug(debug bool) {
 
 // Options specifies user specific options
 type Options struct {
-	IsSender       bool
-	SharedSecret   string
-	RoomName       string
-	Debug          bool
-	RelayAddress   string
-	RelayAddress6  string
-	RelayPorts     []string
-	RelayPassword  string
-	Stdout         bool
-	NoPrompt       bool
-	NoMultiplexing bool
-	DisableLocal   bool
-	OnlyLocal      bool
-	IgnoreStdin    bool
-	Ask            bool
-	SendingText    bool
-	NoCompress     bool
-	IP             string
-	Overwrite      bool
-	Curve          string
-	HashAlgorithm  string
-	ThrottleUpload string
-	ZipFolder      bool
-	TestFlag       bool
-	GitIgnore      bool
+	IsSender         bool
+	SharedSecret     string
+	RoomName         string
+	Debug            bool
+	RelayAddress     string
+	RelayAddress6    string
+	RelayPorts       []string
+	RelayPassword    string
+	Stdout           bool
+	NoPrompt         bool
+	NoMultiplexing   bool
+	DisableLocal     bool
+	OnlyLocal        bool
+	IgnoreStdin      bool
+	Ask              bool
+	SendingText      bool
+	NoCompress       bool
+	IP               string
+	Overwrite        bool
+	Curve            string
+	HashAlgorithm    string
+	ThrottleUpload   string
+	ZipFolder        bool
+	TestFlag         bool
+	GitIgnore        bool
+	MulticastAddress string
 }
 
 type SimpleMessage struct {
@@ -306,7 +308,6 @@ func isChild(parentPath, childPath string) bool {
 		return false
 	}
 	return !strings.HasPrefix(relPath, "..")
-
 }
 
 // This function retrieves the important file information
@@ -329,7 +330,7 @@ func GetFilesInfo(fnames []string, zipfolder bool, ignoreGit bool) (filesInfo []
 			paths = append(paths, fname)
 		}
 	}
-	var ignoredPaths = make(map[string]bool)
+	ignoredPaths := make(map[string]bool)
 	if ignoreGit {
 		wd, wdErr := os.Stat(".gitignore")
 		if wdErr == nil {
@@ -388,6 +389,7 @@ func GetFilesInfo(fnames []string, zipfolder bool, ignoreGit bool) (filesInfo []
 			fpath = filepath.Dir(fpath)
 			dest := filepath.Base(fpath) + ".zip"
 			utils.ZipDirectory(dest, fpath)
+			utils.MarkFileForRemoval(dest)
 			stat, errStat = os.Lstat(dest)
 			if errStat != nil {
 				err = errStat
@@ -587,7 +589,7 @@ func (c *Client) broadcastOnLocalNetwork(useipv6 bool) {
 	if useipv6 {
 		settings.IPVersion = peerdiscovery.IPv6
 	} else {
-		settings.MulticastAddress = "255.255.255.255"
+		settings.MulticastAddress = c.Options.MulticastAddress
 	}
 
 	discoveries, err := peerdiscovery.Discover(settings)
@@ -657,6 +659,7 @@ On the other computer run:
 (For Linux/OSX)
     CROC_SECRET=%[1]q croc %[2]s
 `, c.Options.SharedSecret, flags.String())
+	copyToClipboard(c.Options.SharedSecret)
 	if c.Options.Ask {
 		machid, _ := machineid.ID()
 		fmt.Fprintf(os.Stderr, "\rYour machine ID is '%s'\n", machid)
@@ -868,7 +871,7 @@ func (c *Client) Receive() (err error) {
 				Payload:          []byte("ok"),
 				Delay:            20 * time.Millisecond,
 				TimeLimit:        200 * time.Millisecond,
-				MulticastAddress: "255.255.255.255",
+				MulticastAddress: c.Options.MulticastAddress,
 			})
 			if err1 == nil && len(ipv4discoveries) > 0 {
 				dmux.Lock()
@@ -1219,7 +1222,16 @@ func (c *Client) processMessageFileInfo(m message.Message) (done bool, err error
 	for i, fi := range c.FilesToTransfer {
 		// Issues #593 - sanitize the sender paths and prevent ".." from being used
 		c.FilesToTransfer[i].FolderRemote = filepath.Clean(fi.FolderRemote)
-		if strings.Contains(c.FilesToTransfer[i].FolderRemote, "..") {
+		if strings.Contains(c.FilesToTransfer[i].FolderRemote, "../") {
+			return true, fmt.Errorf("invalid path detected: '%s'", fi.FolderRemote)
+		}
+		if strings.Contains(c.FilesToTransfer[i].FolderRemote, "/..") {
+			return true, fmt.Errorf("invalid path detected: '%s'", fi.FolderRemote)
+		}
+		if strings.Contains(c.FilesToTransfer[i].FolderRemote, "\\..") {
+			return true, fmt.Errorf("invalid path detected: '%s'", fi.FolderRemote)
+		}
+		if strings.Contains(c.FilesToTransfer[i].FolderRemote, "..\\") {
 			return true, fmt.Errorf("invalid path detected: '%s'", fi.FolderRemote)
 		}
 		// Issues #593 - disallow specific folders like .ssh
@@ -2112,3 +2124,27 @@ func (c *Client) sendData(i int) {
 		}
 	}
 }
+
+func copyToClipboard(str string) {
+	var cmd *exec.Cmd
+	switch runtime.GOOS {
+	case "windows":
+		cmd = exec.Command("clip")
+	case "darwin":
+		cmd = exec.Command("pbcopy")
+	case "linux":
+		if os.Getenv("XDG_SESSION_TYPE") == "wayland" {
+			cmd = exec.Command("wl-copy")
+		} else {
+			cmd = exec.Command("xclip", "-selection", "clipboard")
+		}
+	default:
+		return
+	}
+	cmd.Stdin = bytes.NewReader([]byte(str))
+	if err := cmd.Run(); err != nil {
+		log.Debugf("error copying to clipboard: %v", err)
+		return
+	}
+	fmt.Fprintf(os.Stderr, "Code copied to clipboard")
+}
